@@ -27,7 +27,7 @@ from PyQt4.QtCore import *
 from PyQt4.QtGui import *
 
 app_name = "ReText"
-app_version = "3.1.3"
+app_version = "3.1.4"
 
 def readFromSettings(settings, key, keytype):
 	try:
@@ -469,7 +469,6 @@ class ReTextWindow(QMainWindow):
 		self.menuEdit.addAction(self.actionCopy)
 		self.menuEdit.addAction(self.actionPaste)
 		self.menuEdit.addSeparator()
-		self.sc = False
 		if use_enchant:
 			self.menuSC = self.menuEdit.addMenu(self.tr('Spell check'))
 			self.menuSC.addAction(self.actionEnableSC)
@@ -579,9 +578,10 @@ class ReTextWindow(QMainWindow):
 	def actIcon(self, name):
 		return QIcon.fromTheme(name, QIcon(icon_path+name+'.png'))
 	
-	def printError(self, error):
+	def printError(self):
+		import traceback
 		print('Exception occured while parsing document:')
-		print(error)
+		traceback.print_exc()
 	
 	def getSplitter(self, index):
 		splitter = QSplitter(Qt.Horizontal)
@@ -880,8 +880,8 @@ class ReTextWindow(QMainWindow):
 		else:
 			try:
 				parsedText = self.parseText()
-			except Exception as e:
-				self.printError(e)
+			except:
+				self.printError()
 			else:
 				if textedit:
 					pb.setHtml(parsedText)
@@ -1138,8 +1138,8 @@ class ReTextWindow(QMainWindow):
 			fileName += ".html"
 		try:
 			text = self.parseText()
-		except Exception as e:
-			return self.printError(e)
+		except:
+			return self.printError()
 		htmlFile = QFile(fileName)
 		htmlFile.open(QIODevice.WriteOnly)
 		html = QTextStream(htmlFile)
@@ -1171,9 +1171,8 @@ class ReTextWindow(QMainWindow):
 	def saveOdf(self):
 		try:
 			document = self.textDocument()
-		except Exception as e:
-			self.printError(e)
-			return
+		except:
+			return self.printError()
 		fileName = QFileDialog.getSaveFileName(self, self.tr("Export document to ODT"), "", self.tr("OpenDocument text files (*.odt)"))
 		if not QFileInfo(fileName).suffix():
 			fileName += ".odt"
@@ -1192,8 +1191,8 @@ class ReTextWindow(QMainWindow):
 			return self.previewBoxes[self.ind]
 		try:
 			return self.textDocument()
-		except Exception as e:
-			self.printError(e)
+		except:
+			self.printError()
 	
 	def standardPrinter(self):
 		printer = QPrinter(QPrinter.HighResolution)
@@ -1271,21 +1270,21 @@ class ReTextWindow(QMainWindow):
 		"""Ensure that parseText() is called before this function!
 		If 'baseName' is set to True, file basename will be used."""
 		realTitle = ''
-		try:
-			text = unicode(self.editBoxes[self.ind].toPlainText())
-		except:
-			# For Python 3
-			text = self.editBoxes[self.ind].toPlainText()
-		docType = self.getDocType()
-		if docType == DOCTYPE_REST:
-			realTitle = publish_parts(text, writer_name='html')['title']
-		elif docType == DOCTYPE_MARKDOWN:
+		if not baseName:
 			try:
-				realTitle = str.join(' ', md.Meta['title'])
+				text = unicode(self.editBoxes[self.ind].toPlainText())
+			except:
+				# For Python 3
+				text = self.editBoxes[self.ind].toPlainText()
+			docType = self.getDocType()
+			try:
+				if docType == DOCTYPE_REST:
+					realTitle = publish_parts(text, writer_name='html')['title']
+				elif docType == DOCTYPE_MARKDOWN:
+					realTitle = str.join(' ', md.Meta['title'])
 			except:
-				# Meta extension not installed
 				pass
-		if realTitle and not baseName:
+		if realTitle:
 			return realTitle
 		elif self.fileNames[self.ind]:
 			fileinfo = QFileInfo(self.fileNames[self.ind])
@@ -1425,9 +1424,8 @@ class ReTextWindow(QMainWindow):
 		HtmlDlg = HtmlDialog(self)
 		try:
 			HtmlDlg.textEdit.setPlainText(self.parseText())
-		except Exception as e:
-			self.printError(e)
-			return
+		except:
+			return self.printError()
 		winTitle = self.tr('New document')
 		if self.fileNames[self.ind]:
 			winTitle = QFileInfo(self.fileNames[self.ind]).fileName()
