@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="2.0" language="es_ES" sourcelanguage="">
+<!DOCTYPE TS><TS version="2.0" language="es" sourcelanguage="en_US">
 <context>
     <name>LogPassDialog</name>
     <message>
@@ -10,7 +10,7 @@
     <message>
         <location filename="retext.py" line="217"/>
         <source>Username</source>
-        <translation>Usuario</translation>
+        <translation>Nombre de usuario</translation>
     </message>
     <message>
         <location filename="retext.py" line="218"/>
@@ -53,7 +53,7 @@
     <message>
         <location filename="retext.py" line="300"/>
         <source>Save as</source>
-        <translation>Guardar cómo</translation>
+        <translation>Guardar como</translation>
     </message>
     <message>
         <location filename="retext.py" line="302"/>
@@ -63,7 +63,7 @@
     <message>
         <location filename="retext.py" line="304"/>
         <source>Print preview</source>
-        <translation>Vista preliminar de impresión</translation>
+        <translation>Previsualización de impresión</translation>
     </message>
     <message>
         <location filename="retext.py" line="306"/>
@@ -73,7 +73,7 @@
     <message>
         <location filename="retext.py" line="307"/>
         <source>Change default font</source>
-        <translation>Cambiar fuente predeterminada</translation>
+        <translation>Cambiar tipografía predeterminada</translation>
     </message>
     <message>
         <location filename="retext.py" line="308"/>
@@ -83,12 +83,12 @@
     <message>
         <location filename="retext.py" line="312"/>
         <source>Preview</source>
-        <translation>Vista preliminar</translation>
+        <translation>Previsualización</translation>
     </message>
     <message>
         <location filename="retext.py" line="321"/>
         <source>Live preview</source>
-        <translation>Vista preliminar en vivo</translation>
+        <translation>Previsualización en vivo</translation>
     </message>
     <message>
         <location filename="retext.py" line="323"/>
@@ -143,7 +143,7 @@
     <message>
         <location filename="retext.py" line="353"/>
         <source>Use WebKit renderer</source>
-        <translation>Usar intérprete Webkit</translation>
+        <translation>Usar renderizador Webkit</translation>
     </message>
     <message>
         <location filename="retext.py" line="360"/>
@@ -168,7 +168,7 @@
     <message>
         <location filename="retext.py" line="365"/>
         <source>Get help online</source>
-        <translation>Obtener ayuda en-línea</translation>
+        <translation>Obtener ayuda en línea</translation>
     </message>
     <message>
         <location filename="retext.py" line="370"/>
@@ -248,7 +248,7 @@
     <message>
         <location filename="retext.py" line="482"/>
         <source>Default editing mode</source>
-        <translation>Modo de edición por defecto</translation>
+        <translation>Modo de edición predeterminado</translation>
     </message>
     <message>
         <location filename="retext.py" line="485"/>
@@ -263,174 +263,174 @@
     <message>
         <location filename="retext.py" line="526"/>
         <source>Case sensitively</source>
-        <translation>Distinguir mayúsculas/minúsculas</translation>
+        <translation>Distinguir mayúsculas y minúsculas</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1421"/>
+        <location filename="retext.py" line="1431"/>
         <source>New document</source>
-        <translation>Nuevo documento</translation>
+        <translation>Documento nuevo</translation>
     </message>
     <message>
         <location filename="retext.py" line="563"/>
         <source>You have neither Markdown nor Docutils modules installed!</source>
-        <translation>¡No tiene ni el módulo Markdown ni Docutils instalados!</translation>
+        <translation>No tiene el módulo Markdown ni Docutils instalados.</translation>
     </message>
     <message>
         <location filename="retext.py" line="819"/>
         <source>Enter locale name (example: en_US)</source>
-        <translation>Introduzca el nombre del local (por ejemplo: en_US)</translation>
+        <translation>Introduzca el nombre la localización (por ejemplo: es_MX)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="916"/>
+        <location filename="retext.py" line="926"/>
         <source>Please, save the file somewhere.</source>
-        <translation>Salve el fichero en algún lugar.</translation>
+        <translation>Guarde el archivo en algún lugar.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="903"/>
+        <location filename="retext.py" line="913"/>
         <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
         <translation>Páginas web guardadas en el directorio &lt;code&gt;html&lt;/code&gt;.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="905"/>
+        <location filename="retext.py" line="915"/>
         <source>Show directory</source>
         <translation>Mostrar directorio</translation>
     </message>
     <message>
-        <location filename="retext.py" line="910"/>
+        <location filename="retext.py" line="920"/>
         <source>Webpages generator is not installed!</source>
-        <translation>¡El generador de páginas web no está instalado!</translation>
+        <translation>El generador de páginas web no está instalado.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1032"/>
+        <location filename="retext.py" line="1042"/>
         <source>Select one or several files to open</source>
         <translation>Seleccione uno o varios archivos a abrir</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1032"/>
+        <location filename="retext.py" line="1042"/>
         <source>Supported files</source>
-        <translation>Archivos soportados</translation>
+        <translation>Archivos compatibles</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1032"/>
+        <location filename="retext.py" line="1042"/>
         <source>All files (*)</source>
         <translation>Todos los archivos (*)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1091"/>
+        <location filename="retext.py" line="1101"/>
         <source>Plain text (*.txt)</source>
         <translation>Texto plano (*.txt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1094"/>
+        <location filename="retext.py" line="1104"/>
         <source>ReStructuredText files</source>
         <translation>Archivos ReStructuredText</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1097"/>
+        <location filename="retext.py" line="1107"/>
         <source>Markdown files</source>
         <translation>Archivos Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1174"/>
+        <location filename="retext.py" line="1186"/>
         <source>Save file</source>
         <translation>Guardar archivo</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1112"/>
+        <location filename="retext.py" line="1124"/>
         <source>Cannot save to file because it is read-only!</source>
-        <translation>¡No se puede guardar el archivo porque está como sólo-lectura!</translation>
+        <translation>No se puede guardar el archivo porque es de solo lectura.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1165"/>
+        <location filename="retext.py" line="1177"/>
         <source>Export document to ODT</source>
         <translation>Exportar documento a ODT</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1165"/>
+        <location filename="retext.py" line="1177"/>
         <source>OpenDocument text files (*.odt)</source>
         <translation>Archivos de texto OpenDocument (*.odt)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1174"/>
+        <location filename="retext.py" line="1186"/>
         <source>HTML files (*.html *.htm)</source>
         <translation>Archivos HTML (*.html *.htm)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1197"/>
+        <location filename="retext.py" line="1208"/>
         <source>Export document to PDF</source>
         <translation>Exportar documento a PDF</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1197"/>
+        <location filename="retext.py" line="1208"/>
         <source>PDF files (*.pdf)</source>
         <translation>Archivos PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1212"/>
+        <location filename="retext.py" line="1223"/>
         <source>Print document</source>
         <translation>Imprimir documento</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1231"/>
+        <location filename="retext.py" line="1242"/>
         <source>Export document</source>
         <translation>Exportar documento</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1255"/>
+        <location filename="retext.py" line="1265"/>
         <source>Failed to execute the command:</source>
         <translation>Fallo al ejecutar el comando:</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1316"/>
+        <location filename="retext.py" line="1326"/>
         <source>Incorrect user name or password!</source>
-        <translation>¡Nombre de usuario o contraseña incorrectos!</translation>
+        <translation>Nombre de usuario o contraseña incorrectos.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1319"/>
+        <location filename="retext.py" line="1329"/>
         <source>Authentification failed, please check your internet connection!</source>
-        <translation>¡Autenticación fallida. Compruebe su conexión a internet!</translation>
+        <translation>Falló la autenticación, compruebe su conexión a Internet.</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1395"/>
+        <location filename="retext.py" line="1405"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>El documento ha sido modificado.
 ¿Quiere guardar sus cambios?</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1428"/>
+        <location filename="retext.py" line="1438"/>
         <source>HTML code</source>
         <translation>Código HTML</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1437"/>
+        <location filename="retext.py" line="1447"/>
         <source>Simple but powerful editor for Markdown and ReStructuredText</source>
-        <translation>Sencillo pero potente editor para Markdown y ReStructuredText</translation>
+        <translation>Editor para Markdown y ReStructuredText sencillo pero potente</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1437"/>
+        <location filename="retext.py" line="1447"/>
         <source>Author: Dmitry Shachnev, 2011</source>
         <translation>Autor: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1437"/>
+        <location filename="retext.py" line="1447"/>
         <source>Website</source>
         <translation>Sitio web</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1437"/>
+        <location filename="retext.py" line="1447"/>
         <source>Markdown syntax</source>
         <translation>Sintaxis Markdown</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1437"/>
+        <location filename="retext.py" line="1447"/>
         <source>ReST syntax</source>
         <translation>Sintaxis ReST</translation>
     </message>
     <message>
-        <location filename="retext.py" line="1488"/>
+        <location filename="retext.py" line="1498"/>
         <source>Could not parse file contents, check if you have the necessary module installed!</source>
-        <translation>¡No se pudo analizar el contenido del archivo. Compruebe si tiene los módulos necesarios instalados!</translation>
+        <translation>No se pudo analizar el contenido del archivo. Compruebe si tiene los módulos necesarios instalados.</translation>
     </message>
 </context>
 </TS>
